# lipidoz
Python utility for determination of lipid double bond position location from OzID data

#### Contributors:
- Dylan Ross (dylan.ross@pnnl.gov)
- Aivett Bilbao (aivett.bilbao@pnnl.gov)
- Joon-Yong Lee (junyoni@gmail.com)
- Xueyun Zheng (xueyun.zheng@pnnl.gov)

<hr>


Documentation is available at https://lipidoz.readthedocs.io/

